Class: Aws::KeyspacesStreams::Types::KeyspacesMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-keyspacesstreams/types.rb

Overview

Contains metadata information associated with Amazon Keyspaces cells and rows.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#expiration_timeString

The time at which the associated data will expire, based on the time-to-live (TTL) setting.

Returns:

  • (String)


550
551
552
553
554
555
# File 'lib/aws-sdk-keyspacesstreams/types.rb', line 550

class KeyspacesMetadata < Struct.new(
  :expiration_time,
  :write_time)
  SENSITIVE = []
  include Aws::Structure
end

#write_timeString

The timestamp at which the associated data was written to the database.

Returns:

  • (String)


550
551
552
553
554
555
# File 'lib/aws-sdk-keyspacesstreams/types.rb', line 550

class KeyspacesMetadata < Struct.new(
  :expiration_time,
  :write_time)
  SENSITIVE = []
  include Aws::Structure
end