Class: Aws::KeyspacesStreams::Types::KeyspacesRow
- Inherits:
-
Struct
- Object
- Struct
- Aws::KeyspacesStreams::Types::KeyspacesRow
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-keyspacesstreams/types.rb
Overview
Represents a row in an Amazon Keyspaces table, containing regular column values, static column values, and row-level metadata.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#row_metadata ⇒ Types::KeyspacesMetadata
Metadata that applies to the entire row, such as timestamps and TTL information.
-
#static_cells ⇒ Hash<String,Types::KeyspacesCell>
A map of static column cells shared by all rows with the same partition key, where keys are column names and values are the corresponding cells.
-
#value_cells ⇒ Hash<String,Types::KeyspacesCell>
A map of regular (non-static) column cells in the row, where keys are column names and values are the corresponding cells.
Instance Attribute Details
#row_metadata ⇒ Types::KeyspacesMetadata
Metadata that applies to the entire row, such as timestamps and TTL information.
578 579 580 581 582 583 584 |
# File 'lib/aws-sdk-keyspacesstreams/types.rb', line 578 class KeyspacesRow < Struct.new( :value_cells, :static_cells, :row_metadata) SENSITIVE = [] include Aws::Structure end |
#static_cells ⇒ Hash<String,Types::KeyspacesCell>
A map of static column cells shared by all rows with the same partition key, where keys are column names and values are the corresponding cells.
578 579 580 581 582 583 584 |
# File 'lib/aws-sdk-keyspacesstreams/types.rb', line 578 class KeyspacesRow < Struct.new( :value_cells, :static_cells, :row_metadata) SENSITIVE = [] include Aws::Structure end |
#value_cells ⇒ Hash<String,Types::KeyspacesCell>
A map of regular (non-static) column cells in the row, where keys are column names and values are the corresponding cells.
578 579 580 581 582 583 584 |
# File 'lib/aws-sdk-keyspacesstreams/types.rb', line 578 class KeyspacesRow < Struct.new( :value_cells, :static_cells, :row_metadata) SENSITIVE = [] include Aws::Structure end |