Class: Aws::KeyspacesStreams::Types::GetStreamInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::KeyspacesStreams::Types::GetStreamInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-keyspacesstreams/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of shard objects to return in a single ‘GetStream` request.
-
#next_token ⇒ String
An optional pagination token provided by a previous ‘GetStream` operation.
-
#shard_filter ⇒ Types::ShardFilter
Optional filter criteria to apply when retrieving shards.
-
#stream_arn ⇒ String
The Amazon Resource Name (ARN) of the stream for which detailed information is requested.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of shard objects to return in a single ‘GetStream` request. The default value is 100. The minimum value is 1 and the maximum value is 100.
171 172 173 174 175 176 177 178 |
# File 'lib/aws-sdk-keyspacesstreams/types.rb', line 171 class GetStreamInput < Struct.new( :stream_arn, :max_results, :shard_filter, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An optional pagination token provided by a previous ‘GetStream` operation. If this parameter is specified, the response includes only records beyond the token, up to the value specified by `MaxResults`.
171 172 173 174 175 176 177 178 |
# File 'lib/aws-sdk-keyspacesstreams/types.rb', line 171 class GetStreamInput < Struct.new( :stream_arn, :max_results, :shard_filter, :next_token) SENSITIVE = [] include Aws::Structure end |
#shard_filter ⇒ Types::ShardFilter
Optional filter criteria to apply when retrieving shards. You can filter shards based on their parent ‘shardID` to get a list of children shards to narrow down the results returned by the `GetStream` operation.
171 172 173 174 175 176 177 178 |
# File 'lib/aws-sdk-keyspacesstreams/types.rb', line 171 class GetStreamInput < Struct.new( :stream_arn, :max_results, :shard_filter, :next_token) SENSITIVE = [] include Aws::Structure end |
#stream_arn ⇒ String
The Amazon Resource Name (ARN) of the stream for which detailed information is requested. This uniquely identifies the specific stream you want to get information about.
171 172 173 174 175 176 177 178 |
# File 'lib/aws-sdk-keyspacesstreams/types.rb', line 171 class GetStreamInput < Struct.new( :stream_arn, :max_results, :shard_filter, :next_token) SENSITIVE = [] include Aws::Structure end |